function varsels = selsetops(result,set,X,y,nret,nvl)
% SELSETOPS Shows the result of the variable selection for an specific set
% selected by the user. To see the table with all sets of variables
% you should execute VERTABOPS function.
% 
% Input:
%         result: output of execops function (matlab struct).
%         set: desired variables set. See: VERTABOPS.
%         X (m,n): independent variables matrix
%         y (m,1): dependent variable vector
%         nvl: latent variables number desired for model building 
%              If nvl is not provided, a plot and a message will be shown
%              in order to the user choose the desired nvl number
%          nret: number of samples to be removed during cross validation
%  Output:
%        Struct with the selected variables, [Xs(m,s)] matrix with the
%        selected variables where s is the number of selected independent variables,
%        table with the result of the selection and
%        a table with measured and predicted values for dependent variable, residuals
%	and relative errors
% 
% varsels = selsetops(result,set,X,y,nret,nvl);
%
% See also: VECTOPS, VERTABOPS, EXECOPS, OPSWIZERD, OPSWIZARDGUI

%  Copyright  LQTA-Unicamp OPS 1.0, Inc. 2006-2007
%  Any change, recompilation, translation or M-files conversion
%  cannot be done without written permission of
%  LQTA-Unicamp OPS 1.0, Inc.
%
%  Modified 12/06
%  Checked on MATLAB 7 by RFT  13/12/06
%  Added support for cross validation by JPAM 14/12/06
%  Modified 02/07
%  Checked on MATLAB 7 by RFT  15/02/07
%  
%  -standard IO mods

ver = set;
rmsecvout     = result.rmsecvout;
rcvout        = result.rcvout;
var_sel       = result.setvar;
prepro_method = result.prep_method;

[u,h] = size(rmsecvout);
nset = [1:h]';
rmsecv_b = zeros(h,1);
rcv_b = zeros(h,1);
nvl_b = zeros(h,1);
nvars = zeros(h,1);
nseta = length(nvars); % tamanho do vetor dos conjuntos de variveis
nsetb = (1:nseta);

nvls = num2str(nvl_b); % string dos nmero de variveis latentes 
sets = num2str(nset);   % string dos conjuntos de variveis
nvar = num2str(nvars); % string do nmero de variveis selecionadas em cada conjunto

%_____________________________________________

secv = rmsecvout{ver};
secvf = rmsecvout{max(nsetb)};
secvf = secvf(1:length(secv));

rcv = rcvout{ver};
rcvf = rcvout{max(nsetb)};
rcvf = rcvf(1:length(rcv));

varsel = var_sel{ver};
setvar = var_sel;
vet = [1:length(secv)];
[sel,ins] = sort(varsel');
%_____________________________________________

if nargin < 6
    % construo dos grficos
    figure
    plot(X');
    xlabel('Variables')
    ylabel('Intensity')
    title('Selected variables indicated by vertical dotted lines')
    velin(sel,':')
    figure
    subplot(1,2,1)
    plot(vet,secv,'-o',vet,secvf,'-s')
    legend('Selection','All variables')
    xlabel ('Number of latent variables')
    ylabel ('rmsecv(Selection) and rmsecv(All variables)')
    grid on
    subplot(1,2,2)
    plot(vet,rcv,'-o',vet,rcvf,'-s')
    legend('Selection','All variables')
    xlabel ('Number of latent variables')
    ylabel ('Correlation coefficient r')
    grid on
    nvl = input('Enter with the desired number of latent variables (hMod): ');
end
Ts = result.tabela;

% Construo do modelo com as variveis escolhidas
Xs = X(:,[varsel]);
PLSmodel = val_cruzada(Xs,y,nvl,prepro_method,prepro_method,nret);
ycv = PLSmodel.Ypred(:,nvl);
rmsecv = PLSmodel.RMSECV;
r = corrcoef(y,ycv); rcv = r(1,2);
err = (((abs(y-ycv))./y)*100);
res = y-ycv;

nu = (1:length(y))';
T = [nu y ycv res err];

plot(y,ycv,'o');
dlin
xlabel('Measured');
ylabel('CV Predicted');

subplot(1,2,1)
plot(rmsecv,'-o')
title(['RMSECV = ' num2str(rmsecv(nvl))]);
ylabel ('RMSECV')
xlabel ('Number of latent variables')

subplot(1,2,2)
plot(y,ycv,'o');        % Valores preditos pela validao cruzada na VL
dlin
title(['R = ' num2str(rcv)]);
xlabel ('Measured values')
ylabel ('CV predicted values')
rotim = PLSmodel.rcv(:,nvl);

sel = [set length(varsel) nvl rmsecv(nvl) rcv];

txt = cell(0);
txt{end+1} = ('  ');
txt{end+1} = ('              Chosen result                   ');
txt{end+1} = ('  ');
txt{end+1} = ('   ----------------------------------------   ');
txt{end+1} = ('   set.    nVar     nlv     RMSECV    rcv     ');
txt{end+1} = ('   -----   -----    ----    ------    -----   ');
format =      '   %3.0f    %3.0f       %3.0f     %1.4f    %0.3f   ';
for ii=1:1
    txt{end+1} = sprintf(format,sel(ii,:));
end
txt{end+1} = ('   ________________________________________');
disp(sprintf('%s\n',txt{:}));


txt = cell(0);
txt{end+1} = ('  ');
txt{end+1} = ('      Evaluation of the model using its prediction power    ');
txt{end+1} = ('  ');
txt{end+1} = ('   --------------Results of cross validation----------------');
txt{end+1} = ('   samples    measured predicted residuals relative errors(%)');
txt{end+1} = ('   --------   -------  --------  -------- ------------------');
format =      '    %3.0f       %6.2f    %6.2f    %6.2f       %3.2f'          ;
for ii=1:length(y)
    txt{end+1} = sprintf(format,T(ii,:));
end
txt{end+1} = ('   _____________________________________________________');
disp(sprintf('%s\n',txt{:})); % define o nmero de casas decimais e imprime
disp (['  Number of latent variables used:' ' ' num2str(nvl)])
disp (['  rmsecv:' ' ' num2str(rmsecv(nvl))])

varsels.varsel       = varsel;
varsels.Xs           = Xs;
varsels.nameTSEL     = {'Set.' 'nVar' 'nlv' 'RMSECV' 'rcv'};
varsels.resultSEL    = sel;
varsels.tabMPRE      = T;
