function [vectors] = vectops(X,y,prepro_method,nret,nvl)
% VECTOPS Generates vectors and their respective indexes to be used 
% in the variables ordering of X matrix
% Input:
%          X (m,n): independent variables
%          y (m,1): dependent variables
%         prepro_method : string containing the desired preprocessing method
%                          Mean center = 'mean', autoscale = 'auto', 
%                          none = 'none'
%          default: 'auto'
%          nvl(optional): desired latent variables number. If nvl is not provided
%          a cross validation is performed, a graph is shown in the screen and a
%          message is shown asking to the user the desired nvl
%          nret: number of samples to be removed during cross validation
% Output:
%          vectors: informative vectors
%                   reg:  regression vector.
%                   corr: correlation vector.
%                   prod: reg and corr element wise product.
%
% [vectors] = vectops(X,y,prepro_method,nret,nvl)
%
% See also: SELVECTOPS, EXECOPS, ESCVLOPS, OPSWIZARD, OPSWIZARDGUI

%  Copyright  LQTA-Unicamp OPS 1.0, Inc. 2006-2007
%  Any change, recompilation, translation or M-files conversion
%  cannot be done without written permission of
%  LQTA-Unicamp OPS 1.0, Inc.
%
%  Modified 12/06
%  Checked on MATLAB 7 by RFT  13/12/06
%  Added support for cross validation by JPAM 14/12/06
%  Modified 02/07
%  Checked on MATLAB 7 by RFT  15/02/07
%
%  -standard IO mods
if nargin == 2
    prepro_method = 1;
else
    if strcmp(lower(prepro_method),'auto')
        prepro_method = 1;
    elseif strcmp(lower(prepro_method),'mean')
        prepro_method = 2;
    elseif strcmp(lower(prepro_method),'none')
        prepro_method = 3;
    end
end

if nargin < 5
    escvlops(X,y,prepro_method,nret) % funo para gerar o grfico 
                                % variveis latentes vs. RMSECV
    nvl = input('enter with the desired number of latent variables (hOPS):');
    close all
end

Xp = preprocessa(X,prepro_method);
yp = preprocessa(y,prepro_method);

B = opsimpls(Xp,yp,nvl); %Constri o modelo usando a regresso PLS

b = B(:,nvl);        % vetor de regresso na varivel latente npc
ba = abs(b);          % valor absoluto de b.
bn = ba/norm(ba,inf); % normalizando o vetor de regresso

corr = correlograma(X,y); % vetor de correlao entre X e y 
corra = abs(corr);        % valor absoluto do vetor de correlao

prod = bn.*corra;         % vetor obtido pelo produto entre b e corr

close all
figure
[m,n] = size(X);
var = [1:n];

subplot(2,2,1)
plot(var,X)
axis tight
xlabel ('Variables')
ylabel ('Intensity')
title('Original data')

subplot(2,2,2)
plot(var,ba,'-b')
axis tight
xlabel ('Variables')
ylabel ('Intensity')
title('Regression vector (absolute value)')

subplot(2,2,3)
plot(prod,'k-')
axis tight
xlabel ('Variables')
ylabel ('Intensity')
title('Product vector')

subplot(2,2,4)
plot(var,corra,'-r')
axis tight
xlabel ('Variables')
ylabel ('correlations X y')
title('Correlation vector (absolute value)')

vectors.reg  = ba;
vectors.corr = corra;
vectors.prod = prod;